pub enum CacheAccounting {
Subset,
Additive,
}Expand description
How a provider reports cache tokens relative to its input token count.
Variants
Subset
Cache tokens are a subset of the reported input tokens
(OpenAI, Azure, OpenRouter, Groq, xAI, DeepSeek, …).
Additive
Cache tokens are reported in addition to the input tokens
(Anthropic Messages and AWS Bedrock Converse).