pub struct TestGroup {
pub name: String,
pub start_url: Option<String>,
pub auto_navigate: Option<bool>,
pub base_url: Option<String>,
pub timeout_secs: Option<u64>,
pub browser_headless: Option<bool>,
pub budget: Option<BudgetDef>,
pub endpoint: Option<String>,
pub steps: Vec<TestStep>,
}Expand description
A group of steps that form a single test scenario.
Fields
name: StringHuman-readable test name.
start_url: Option<String>Override the global start_url for this test.
Override the global auto_navigate for this test.
base_url: Option<String>Override the global base_url for this test.
timeout_secs: Option<u64>Override the global timeout_secs for this test.
browser_headless: Option<bool>Override the global browser_headless for this test.
budget: Option<BudgetDef>Per-test budget override.
endpoint: Option<String>Endpoint to use for all steps in this test (can be overridden per-step).
steps: Vec<TestStep>Ordered steps to execute.