UsageSnapshot

Struct UsageSnapshot 

pub struct UsageSnapshot {
    pub endpoints: HashMap<String, EndpointUsage>,
    pub total_cost: f64,
    pub total_calls: u64,
    pub total_tokens: u64,
    pub total_input_tokens: u64,
    pub total_output_tokens: u64,
    pub total_cached_input_tokens: u64,
    pub total_cache_creation_input_tokens: u64,
    pub models: Vec<String>,
}
Aggregated usage across all endpoints for a test or scenario run.

Fields

endpoints: HashMap<String, EndpointUsage>

Per-endpoint usage.

total_cost: f64

Total cost across all endpoints.

total_calls: u64

Total calls across all endpoints.

total_tokens: u64

Total tokens across all endpoints.

total_input_tokens: u64

Total input (prompt) tokens across all endpoints.

total_output_tokens: u64

Total output (completion) tokens across all endpoints.

total_cached_input_tokens: u64

Total input tokens served from provider prompt caches.

total_cache_creation_input_tokens: u64

Total input tokens written to provider prompt caches.

models: Vec<String>

Model names observed across all endpoints, sorted and deduplicated.

Implementations

Source

impl UsageSnapshot

pub fn from_endpoints(endpoints: &HashMap<String, EndpointUsage>) -> Self

Creates a snapshot from per-endpoint usage data.